summaryrefslogtreecommitdiffstats
path: root/src/usr/diag/prdf/common/framework/service/prdfRasServices_common.H
diff options
context:
space:
mode:
authorZane Shelley <zshelle@us.ibm.com>2014-07-21 11:13:57 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2014-09-17 11:18:52 -0500
commit754f596ca241911bd69790a550f618a5f879f9d4 (patch)
tree1e9c47924a31ae781105f182347622c8370e6e9f /src/usr/diag/prdf/common/framework/service/prdfRasServices_common.H
parent714d99c2991338cb15b5a5aa83990f5e27877b3c (diff)
downloadtalos-hostboot-754f596ca241911bd69790a550f618a5f879f9d4.tar.gz
talos-hostboot-754f596ca241911bd69790a550f618a5f879f9d4.zip
PRD: Cleaned up RasServices class
Change-Id: Id7d40ff079a34bf7ebfc3a6eea7c33a9d92f37b7 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/12401 Tested-by: Jenkins Server Reviewed-by: Christopher T. Phan <cphan@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com> Reviewed-by: Zane Shelley <zshelle@us.ibm.com> Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/13426
Diffstat (limited to 'src/usr/diag/prdf/common/framework/service/prdfRasServices_common.H')
-rw-r--r--src/usr/diag/prdf/common/framework/service/prdfRasServices_common.H96
1 files changed, 38 insertions, 58 deletions
diff --git a/src/usr/diag/prdf/common/framework/service/prdfRasServices_common.H b/src/usr/diag/prdf/common/framework/service/prdfRasServices_common.H
index e1c650e98..de953dd2e 100644
--- a/src/usr/diag/prdf/common/framework/service/prdfRasServices_common.H
+++ b/src/usr/diag/prdf/common/framework/service/prdfRasServices_common.H
@@ -54,22 +54,16 @@ class ErrDataService
{
public:
- /**
- * @brief ctor
- */
- inline ErrDataService() :
+ /** @brief Constructor */
+ ErrDataService() :
iv_serviceActionCounter(0),
iv_errl(NULL)
{}
- /**
- * @brief dtor
- */
- inline virtual ~ErrDataService() {}
+ /** @brief Destructor */
+ virtual ~ErrDataService() {}
- /**
- * @brief initializer
- */
+ /** @brief Initializer */
virtual void Initialize();
/**
@@ -110,8 +104,8 @@ class ErrDataService
void MnfgTrace( ErrorSignature * i_esig, const PfaData & i_pfaData );
/**
* @brief Create initial error log for analyze( attn analysis) code flow.
* @param i_attnType attention type.
*/
void createInitialErrl( ATTENTION_TYPE i_attnType );
@@ -129,20 +123,18 @@ class ErrDataService
/**
* @brief Return error log associated with current analysis flow.
- * @return error log handle.
+ * @note For normal analysis paths only. Will return NULL if
+ createInitialErrl() has not been called in PRDF::main().
+ * @return An error log.
*/
- errlHndl_t getErrl() { return iv_errl; };
+ errlHndl_t getErrl() const { return iv_errl; }
private:
- /**
- * @brief disable copy
- */
+ /** @brief Disable copy. */
ErrDataService(const ErrDataService &);
- /**
- * @brief disable assignment
- */
+ /** @brief Disable assignment. */
ErrDataService & operator=(const ErrDataService &);
#ifndef __HOSTBOOT_MODULE
@@ -265,33 +257,25 @@ class ErrDataService
};
-/**
- Interface to RAS services provided to PRD
-*/
-class RasServices: public ServiceGeneratorClass
+/** Interface to RAS services provided to PRD */
+class RasServices : public ServiceGeneratorClass
{
-public:
-
- /**
- @brief Default ctor
- */
- RasServices(void);
+ public:
- /**
- @brief Default dtor
- */
- ~RasServices();
+ /** @brief Constructor */
+ RasServices();
- // Compiler generated dtor is sufficient
+ /** @brief Destructor */
+ ~RasServices();
- virtual void Initialize();
+ /** @brief Initializer */
+ virtual void Initialize();
- /**
- * @brief set the err data service to be used
- *
- * @param[in] i_ErrDataService new err data service
- */
- virtual void setErrDataService(ErrDataService & i_ErrDataService);
+ /**
+ * @brief Sets the ErrDataService to be used.
+ * @param i_eds Target ErrDataService.
+ */
+ virtual void setErrDataService( ErrDataService & i_eds );
/**
* @brief Creates an SRC, PFA data, and error log from the SDC provided.
@@ -313,26 +297,22 @@ public:
uint32_t & o_dumpErrlActions );
/**
* @brief Create initial error log for analyze( attn analysis) code flow.
* @param i_attnType attention type.
*/
- void createInitialErrl( ATTENTION_TYPE i_attnType )
- {
- iv_ErrDataService->createInitialErrl( i_attnType );
- }
+ virtual void createInitialErrl( ATTENTION_TYPE i_attnType );
/**
* @brief Return error log associated with current analysis flow.
- * @return error log handle.
+ * @note For normal analysis paths only. Will return NULL if
+ createInitialErrl() has not been called in PRDF::main().
+ * @return An error log.
*/
- virtual errlHndl_t getErrl()
- {
- return iv_ErrDataService->getErrl();
- };
-
-private: // Data
- // actual or sim err data service
- ErrDataService * iv_ErrDataService;
+ virtual errlHndl_t getErrl() const;
+
+ private: // instance variables
+
+ ErrDataService * iv_eds; ///< Actual or simulated ErrDataService.
};
OpenPOWER on IntegriCloud
@@ -110,8 +104,8 @@ class ErrDataService
void MnfgTrace( ErrorSignature * i_esig, const PfaData & i_pfaData );
/**
- * @brief Create initial error log for analyze( attn analysis) code flow.
- * @param i_attnType attention type.
+ * @brief Creates the initial error log for PRDF::main() analysis path.
+ * @param i_attnType Analysis attention type.
*/
void createInitialErrl( ATTENTION_TYPE i_attnType );
@@ -313,26 +297,22 @@ public:
uint32_t & o_dumpErrlActions );
/**
- * @brief Create initial error log for analyze( attn analysis) code flow.
- * @param i_attnType attention type.
+ * @brief Creates the initial error log for PRDF::main() analysis path.
+ * @param i_attnType Analysis attention type.
*/